#ifndef NT2_INCLUDE_CONSTANTS_ONE_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_ONE_HPP_INCLUDED

#include <nt2/constant/include/constants/one.hpp>

#endif
